@@ -23,7 +23,12 @@ struct ax_calls {
  */
 typedef enum {PK_INVALID=-1,PK_VALID=0,PK_VALDIGI=1} pk_val;
 extern pk_val parse_raw_ax25(unsigned char **, int *, struct ax_calls *);
+/* parse a received cooked TNC-2 or AEA format data frame */
+extern pk_val parse_cooked_ax25(unsigned char **, int *, struct ax_calls *);
+/* generate a raw kiss data frame header (converse of parse_raw_ax25) */
 extern int gen_raw_ax25(unsigned char **, int *, struct ax_calls *);
+/* generate a cooked TNC-2 format data frame header (converse of parse_cooked_ax25) */
+extern int gen_cooked_ax25(unsigned char **, int *, struct ax_calls *);
 
 /* pretty version of stand libax25's ax25_ntoa */
 extern char *ax25_ntoa_pretty(const ax25_address *a);
